==> cdktf-provider-aws-10.0.5-sources.jar: com/hashicorp/cdktf/providers/aws/qldb_stream/QldbStreamKinesisConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.qldb_stream;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.69.0 (build f656c31)", date = "2022-10-07T01:25:55.139Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.qldbStream.QldbStreamKinesisConfiguration")
@software.amazon.jsii.Jsii.Proxy(QldbStreamKinesisConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface QldbStreamKinesisConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/qldb_stream#stream_arn QldbStream#stream_arn}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getStreamArn();

    /**
     * Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/qldb_stream#aggregation_enabled QldbStream#aggregation_enabled}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAggregationEnabled() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link QldbStreamKinesisConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link QldbStreamKinesisConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<QldbStreamKinesisConfiguration> {
        java.lang.String streamArn;
        java.lang.Object aggregationEnabled;

        /**
         * Sets the value of {@link QldbStreamKinesisConfiguration#getStreamArn}
         * @param streamArn Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/qldb_stream#stream_arn QldbStream#stream_arn}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder streamArn(java.lang.String streamArn) {
            this.streamArn = streamArn;
            return this;
        }

        /**
         * Sets the value of {@link QldbStreamKinesisConfiguration#getAggregationEnabled}
         * @param aggregationEnabled Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/qldb_stream#aggregation_enabled QldbStream#aggregation_enabled}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder aggregationEnabled(java.lang.Boolean aggregationEnabled) {
            this.aggregationEnabled = aggregationEnabled;
            return this;
        }

        /**
         * Sets the value of {@link QldbStreamKinesisConfiguration#getAggregationEnabled}
         * @param aggregationEnabled Docs at Terraform Registry: {@link https://www.terraform.io/docs/providers/aws/r/qldb_stream#aggregation_enabled QldbStream#aggregation_enabled}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder aggregationEnabled(com.hashicorp.cdktf.IResolvable aggregationEnabled) {
            this.aggregationEnabled = aggregationEnabled;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link QldbStreamKinesisConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public QldbStreamKinesisConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link QldbStreamKinesisConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements QldbStreamKinesisConfiguration {
        private final java.lang.String streamArn;
        private final java.lang.Object aggregationEnabled;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.streamArn = software.amazon.jsii.Kernel.get(this, "streamArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.aggregationEnabled = software.amazon.jsii.Kernel.get(this, "aggregationEnabled", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.streamArn = java.util.Objects.requireNonNull(builder.streamArn, "streamArn is required");
            this.aggregationEnabled = builder.aggregationEnabled;
        }

        @Override
        public final java.lang.String getStreamArn() {
            return this.streamArn;
        }

        @Override
        public final java.lang.Object getAggregationEnabled() {
            return this.aggregationEnabled;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("streamArn", om.valueToTree(this.getStreamArn()));
            if (this.getAggregationEnabled() != null) {
                data.set("aggregationEnabled", om.valueToTree(this.getAggregationEnabled()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.qldbStream.QldbStreamKinesisConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            QldbStreamKinesisConfiguration.Jsii$Proxy that = (QldbStreamKinesisConfiguration.Jsii$Proxy) o;

            if (!streamArn.equals(that.streamArn)) return false;
            return this.aggregationEnabled != null ? this.aggregationEnabled.equals(that.aggregationEnabled) : that.aggregationEnabled == null;
        }

        @Override
        public final int hashCode() {
            int result = this.streamArn.hashCode();
            result = 31 * result + (this.aggregationEnabled != null ? this.aggregationEnabled.hashCode() : 0);
            return result;
        }
    }
}

==> cdktf-provider-aws-16.0.4-sources.jar: com/hashicorp/cdktf/providers/aws/qldb_stream/QldbStreamKinesisConfiguration.java <==
package com.hashicorp.cdktf.providers.aws.qldb_stream;

/**
 */
@javax.annotation.Generated(value = "jsii-pacmak/1.85.0 (build 08ee592)", date = "2023-07-21T05:23:11.165Z")
@software.amazon.jsii.Jsii(module = com.hashicorp.cdktf.providers.aws.$Module.class, fqn = "@cdktf/provider-aws.qldbStream.QldbStreamKinesisConfiguration")
@software.amazon.jsii.Jsii.Proxy(QldbStreamKinesisConfiguration.Jsii$Proxy.class)
@software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
public interface QldbStreamKinesisConfiguration extends software.amazon.jsii.JsiiSerializable {

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/qldb_stream#stream_arn QldbStream#stream_arn}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @org.jetbrains.annotations.NotNull java.lang.String getStreamArn();

    /**
     * Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/qldb_stream#aggregation_enabled QldbStream#aggregation_enabled}.
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    default @org.jetbrains.annotations.Nullable java.lang.Object getAggregationEnabled() {
        return null;
    }

    /**
     * @return a {@link Builder} of {@link QldbStreamKinesisConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    static Builder builder() {
        return new Builder();
    }
    /**
     * A builder for {@link QldbStreamKinesisConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    public static final class Builder implements software.amazon.jsii.Builder<QldbStreamKinesisConfiguration> {
        java.lang.String streamArn;
        java.lang.Object aggregationEnabled;

        /**
         * Sets the value of {@link QldbStreamKinesisConfiguration#getStreamArn}
         * @param streamArn Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/qldb_stream#stream_arn QldbStream#stream_arn}. This parameter is required.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder streamArn(java.lang.String streamArn) {
            this.streamArn = streamArn;
            return this;
        }

        /**
         * Sets the value of {@link QldbStreamKinesisConfiguration#getAggregationEnabled}
         * @param aggregationEnabled Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/qldb_stream#aggregation_enabled QldbStream#aggregation_enabled}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder aggregationEnabled(java.lang.Boolean aggregationEnabled) {
            this.aggregationEnabled = aggregationEnabled;
            return this;
        }

        /**
         * Sets the value of {@link QldbStreamKinesisConfiguration#getAggregationEnabled}
         * @param aggregationEnabled Docs at Terraform Registry: {@link https://registry.terraform.io/providers/hashicorp/aws/5.9.0/docs/resources/qldb_stream#aggregation_enabled QldbStream#aggregation_enabled}.
         * @return {@code this}
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        public Builder aggregationEnabled(com.hashicorp.cdktf.IResolvable aggregationEnabled) {
            this.aggregationEnabled = aggregationEnabled;
            return this;
        }

        /**
         * Builds the configured instance.
         * @return a new instance of {@link QldbStreamKinesisConfiguration}
         * @throws NullPointerException if any required attribute was not provided
         */
        @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
        @Override
        public QldbStreamKinesisConfiguration build() {
            return new Jsii$Proxy(this);
        }
    }

    /**
     * An implementation for {@link QldbStreamKinesisConfiguration}
     */
    @software.amazon.jsii.Stability(software.amazon.jsii.Stability.Level.Stable)
    @software.amazon.jsii.Internal
    final class Jsii$Proxy extends software.amazon.jsii.JsiiObject implements QldbStreamKinesisConfiguration {
        private final java.lang.String streamArn;
        private final java.lang.Object aggregationEnabled;

        /**
         * Constructor that initializes the object based on values retrieved from the JsiiObject.
         * @param objRef Reference to the JSII managed object.
         */
        protected Jsii$Proxy(final software.amazon.jsii.JsiiObjectRef objRef) {
            super(objRef);
            this.streamArn = software.amazon.jsii.Kernel.get(this, "streamArn", software.amazon.jsii.NativeType.forClass(java.lang.String.class));
            this.aggregationEnabled = software.amazon.jsii.Kernel.get(this, "aggregationEnabled", software.amazon.jsii.NativeType.forClass(java.lang.Object.class));
        }

        /**
         * Constructor that initializes the object based on literal property values passed by the {@link Builder}.
         */
        protected Jsii$Proxy(final Builder builder) {
            super(software.amazon.jsii.JsiiObject.InitializationMode.JSII);
            this.streamArn = java.util.Objects.requireNonNull(builder.streamArn, "streamArn is required");
            this.aggregationEnabled = builder.aggregationEnabled;
        }

        @Override
        public final java.lang.String getStreamArn() {
            return this.streamArn;
        }

        @Override
        public final java.lang.Object getAggregationEnabled() {
            return this.aggregationEnabled;
        }

        @Override
        @software.amazon.jsii.Internal
        public com.fasterxml.jackson.databind.JsonNode $jsii$toJson() {
            final com.fasterxml.jackson.databind.ObjectMapper om = software.amazon.jsii.JsiiObjectMapper.INSTANCE;
            final com.fasterxml.jackson.databind.node.ObjectNode data = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();

            data.set("streamArn", om.valueToTree(this.getStreamArn()));
            if (this.getAggregationEnabled() != null) {
                data.set("aggregationEnabled", om.valueToTree(this.getAggregationEnabled()));
            }

            final com.fasterxml.jackson.databind.node.ObjectNode struct = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            struct.set("fqn", om.valueToTree("@cdktf/provider-aws.qldbStream.QldbStreamKinesisConfiguration"));
            struct.set("data", data);

            final com.fasterxml.jackson.databind.node.ObjectNode obj = com.fasterxml.jackson.databind.node.JsonNodeFactory.instance.objectNode();
            obj.set("$jsii.struct", struct);

            return obj;
        }

        @Override
        public final boolean equals(final Object o) {
            if (this == o) return true;
            if (o == null || getClass() != o.getClass()) return false;

            QldbStreamKinesisConfiguration.Jsii$Proxy that = (QldbStreamKinesisConfiguration.Jsii$Proxy) o;

            if (!streamArn.equals(that.streamArn)) return false;
            return this.aggregationEnabled != null ? this.aggregationEnabled.equals(that.aggregationEnabled) : that.aggregationEnabled == null;
        }

        @Override
        public final int hashCode() {
            int result = this.streamArn.hashCode();
            result = 31 * result + (this.aggregationEnabled != null ? this.aggregationEnabled.hashCode() : 0);
            return result;
        }
    }
}
